@@ -11,7 +11,7 @@ class GroupsDelete(Service):
     """Deletes a user."""
 
     def __init__(self, context, request):
-        super(GroupsDelete, self).__init__(context, request)
+        super().__init__(context, request)
         self.params = []
 
     def publishTraverse(self, request, name):
