@@ -14,6 +14,8 @@ class SystemGet(Service):
     def reply(self):
         overview_control_panel = OverviewControlPanel(self.context, self.request)
         core_versions = overview_control_panel.core_versions()
+        gs_fs = core_versions.get("Plone File System")
+        gs_instance = core_versions.get("Plone Instance")
         return {
             "@id": f"{self.context.absolute_url()}/@system",
             "zope_version": core_versions.get("Zope"),
@@ -23,8 +25,7 @@ class SystemGet(Service):
             "cmf_version": core_versions.get("CMF"),
             "pil_version": core_versions.get("PIL"),
             "debug_mode": core_versions.get("Debug mode"),
-            "plone_gs_metadata_version_installed": core_versions.get("Plone Instance"),
-            "plone_gs_metadata_version_file_system": core_versions.get(
-                "Plone File System"
-            ),
+            "plone_gs_metadata_version_installed": gs_instance,
+            "plone_gs_metadata_version_file_system": gs_fs,
+            "upgrade": gs_fs != gs_instance,
         }
